from django.conf.urls import url
from .views import resources, resource_output

app_name = 'resckeditor'
urlpatterns = [
    url(r'^$', resources, name='dialog-data'),
    url(r'^output/$', resource_output, name='output'),
]



import importlib
import json

from django.http import JsonResponse, HttpResponse
from django.http.response import Http404
from django.utils.translation import gettext_lazy as _
from django.conf import settings


def is_allowed(res):
    """ Check if the given module is defined in the configuration object
        Since this app auto imports such module, better be sure only configured
        modules can be loaded
    """
    resources = settings.RESCKEDITOR_CONFIG.get('RESOURCES', [])
    for r in resources:
        if (r.get('list', None) == res or r.get('output', None) == res):
            return True
    return False


def resources(request):
    """ Lists available resources if module is not given
        otherwise returns resources list and options
    """
    res = request.GET.get('res', None)
    if res:
        if is_allowed(res):
            parts = res.split('.')
            module = importlib.import_module('.'.join(parts[:-1]))
            data = getattr(module, parts[-1])()
            res = []
            for r in data.get('resources'):
                res.append({
                    'label': r['label'],
                    'id': r['id']
                })
            data = {
                'res': res,
                'options': data.get('options')
            }
        else:
            raise Exception(_('resckeditor, resource not recognized'))
    else:
        try:
            RESOURCES = settings.RESCKEDITOR_CONFIG.get('RESOURCES', [])
        except AttributeError:
            RESOURCES = []
        data = {
            'resources': RESOURCES,
        }
    return JsonResponse(data)


def resource_output(request):
    """ App view output """
    res = request.GET.get('res', None)
    id = request.GET.get('id', None)
    if not is_allowed(res) or not id:
        raise Http404()

    options = request.GET.get('opt', None)

    try:
        parts = res.split('.')
        module = importlib.import_module('.'.join(parts[:-1]))
        html = getattr(module, parts[-1])(id, json.loads(options))
    except AttributeError:
        html = ''

    return HttpResponse(html)



import os
from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-resckeditor',
    version='1.0.0',
    packages=['resckeditor', ],
    include_package_data=True,
    license='MIT License',
    description='A django app which provides and infrastructure you can use to include custom contents of other apps directly inside ckeditor.',
    long_description=README,
    url='http://github.com/otto-torino/django-resckeditor',
    author='abidibo',
    author_email='abidibo@gmail.com',
    install_requires=[
        'django-ckeditor'
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.5',
        'Topic :: Software Development',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ]
)
